@@ -17,7 +17,16 @@ from typing import IO, Any, Dict, List, Type, Union, overload
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_appsync.paginator import (
+from .literals import (
+    ApiCacheTypeType,
+    ApiCachingBehaviorType,
+    AuthenticationTypeType,
+    DataSourceTypeType,
+    OutputTypeType,
+    ResolverKindType,
+    TypeDefinitionFormatType,
+)
+from .paginator import (
     ListApiKeysPaginator,
     ListDataSourcesPaginator,
     ListFunctionsPaginator,
@@ -26,16 +35,6 @@ from mypy_boto3_appsync.paginator import (
     ListResolversPaginator,
     ListTypesPaginator,
 )
-
-from .literals import (
-    ApiCacheType,
-    ApiCachingBehavior,
-    AuthenticationType,
-    DataSourceType,
-    OutputType,
-    ResolverKind,
-    TypeDefinitionFormat,
-)
 from .type_defs import (
     AdditionalAuthenticationProviderTypeDef,
     CachingConfigTypeDef,
@@ -116,7 +115,7 @@ class Exceptions:
 
 class AppSyncClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -125,37 +124,37 @@ class AppSyncClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def create_api_cache(
         self,
         apiId: str,
         ttl: int,
-        apiCachingBehavior: ApiCachingBehavior,
-        type: ApiCacheType,
+        apiCachingBehavior: ApiCachingBehaviorType,
+        type: ApiCacheTypeType,
         transitEncryptionEnabled: bool = None,
         atRestEncryptionEnabled: bool = None,
     ) -> CreateApiCacheResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.create_api_cache)
-        [Show boto3-stubs documentation](./client.md#create-api-cache)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.create_api_cache)
+        [Show boto3-stubs documentation](./client.md#create_api_cache)
         """
 
     def create_api_key(
         self, apiId: str, description: str = None, expires: int = None
     ) -> CreateApiKeyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.create_api_key)
-        [Show boto3-stubs documentation](./client.md#create-api-key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.create_api_key)
+        [Show boto3-stubs documentation](./client.md#create_api_key)
         """
 
     def create_data_source(
         self,
         apiId: str,
         name: str,
-        type: DataSourceType,
+        type: DataSourceTypeType,
         description: str = None,
         serviceRoleArn: str = None,
         dynamodbConfig: "DynamodbDataSourceConfigTypeDef" = None,
@@ -165,8 +164,8 @@ class AppSyncClient:
         relationalDatabaseConfig: "RelationalDatabaseDataSourceConfigTypeDef" = None,
     ) -> CreateDataSourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.create_data_source)
-        [Show boto3-stubs documentation](./client.md#create-data-source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.create_data_source)
+        [Show boto3-stubs documentation](./client.md#create_data_source)
         """
 
     def create_function(
@@ -181,14 +180,14 @@ class AppSyncClient:
         syncConfig: "SyncConfigTypeDef" = None,
     ) -> CreateFunctionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.create_function)
-        [Show boto3-stubs documentation](./client.md#create-function)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.create_function)
+        [Show boto3-stubs documentation](./client.md#create_function)
         """
 
     def create_graphql_api(
         self,
         name: str,
-        authenticationType: AuthenticationType,
+        authenticationType: AuthenticationTypeType,
         logConfig: "LogConfigTypeDef" = None,
         userPoolConfig: "UserPoolConfigTypeDef" = None,
         openIDConnectConfig: "OpenIDConnectConfigTypeDef" = None,
@@ -197,8 +196,8 @@ class AppSyncClient:
         xrayEnabled: bool = None,
     ) -> CreateGraphqlApiResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.create_graphql_api)
-        [Show boto3-stubs documentation](./client.md#create-graphql-api)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.create_graphql_api)
+        [Show boto3-stubs documentation](./client.md#create_graphql_api)
         """
 
     def create_resolver(
@@ -209,70 +208,70 @@ class AppSyncClient:
         dataSourceName: str = None,
         requestMappingTemplate: str = None,
         responseMappingTemplate: str = None,
-        kind: ResolverKind = None,
+        kind: ResolverKindType = None,
         pipelineConfig: "PipelineConfigTypeDef" = None,
         syncConfig: "SyncConfigTypeDef" = None,
         cachingConfig: "CachingConfigTypeDef" = None,
     ) -> CreateResolverResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.create_resolver)
-        [Show boto3-stubs documentation](./client.md#create-resolver)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.create_resolver)
+        [Show boto3-stubs documentation](./client.md#create_resolver)
         """
 
     def create_type(
-        self, apiId: str, definition: str, format: TypeDefinitionFormat
+        self, apiId: str, definition: str, format: TypeDefinitionFormatType
     ) -> CreateTypeResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.create_type)
-        [Show boto3-stubs documentation](./client.md#create-type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.create_type)
+        [Show boto3-stubs documentation](./client.md#create_type)
         """
 
     def delete_api_cache(self, apiId: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.delete_api_cache)
-        [Show boto3-stubs documentation](./client.md#delete-api-cache)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.delete_api_cache)
+        [Show boto3-stubs documentation](./client.md#delete_api_cache)
         """
 
     def delete_api_key(self, apiId: str, id: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.delete_api_key)
-        [Show boto3-stubs documentation](./client.md#delete-api-key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.delete_api_key)
+        [Show boto3-stubs documentation](./client.md#delete_api_key)
         """
 
     def delete_data_source(self, apiId: str, name: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.delete_data_source)
-        [Show boto3-stubs documentation](./client.md#delete-data-source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.delete_data_source)
+        [Show boto3-stubs documentation](./client.md#delete_data_source)
         """
 
     def delete_function(self, apiId: str, functionId: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.delete_function)
-        [Show boto3-stubs documentation](./client.md#delete-function)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.delete_function)
+        [Show boto3-stubs documentation](./client.md#delete_function)
         """
 
     def delete_graphql_api(self, apiId: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.delete_graphql_api)
-        [Show boto3-stubs documentation](./client.md#delete-graphql-api)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.delete_graphql_api)
+        [Show boto3-stubs documentation](./client.md#delete_graphql_api)
         """
 
     def delete_resolver(self, apiId: str, typeName: str, fieldName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.delete_resolver)
-        [Show boto3-stubs documentation](./client.md#delete-resolver)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.delete_resolver)
+        [Show boto3-stubs documentation](./client.md#delete_resolver)
         """
 
     def delete_type(self, apiId: str, typeName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.delete_type)
-        [Show boto3-stubs documentation](./client.md#delete-type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.delete_type)
+        [Show boto3-stubs documentation](./client.md#delete_type)
         """
 
     def flush_api_cache(self, apiId: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.flush_api_cache)
-        [Show boto3-stubs documentation](./client.md#flush-api-cache)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.flush_api_cache)
+        [Show boto3-stubs documentation](./client.md#flush_api_cache)
         """
 
     def generate_presigned_url(
@@ -283,169 +282,173 @@ class AppSyncClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_api_cache(self, apiId: str) -> GetApiCacheResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.get_api_cache)
-        [Show boto3-stubs documentation](./client.md#get-api-cache)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.get_api_cache)
+        [Show boto3-stubs documentation](./client.md#get_api_cache)
         """
 
     def get_data_source(self, apiId: str, name: str) -> GetDataSourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.get_data_source)
-        [Show boto3-stubs documentation](./client.md#get-data-source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.get_data_source)
+        [Show boto3-stubs documentation](./client.md#get_data_source)
         """
 
     def get_function(self, apiId: str, functionId: str) -> GetFunctionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.get_function)
-        [Show boto3-stubs documentation](./client.md#get-function)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.get_function)
+        [Show boto3-stubs documentation](./client.md#get_function)
         """
 
     def get_graphql_api(self, apiId: str) -> GetGraphqlApiResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.get_graphql_api)
-        [Show boto3-stubs documentation](./client.md#get-graphql-api)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.get_graphql_api)
+        [Show boto3-stubs documentation](./client.md#get_graphql_api)
         """
 
     def get_introspection_schema(
-        self, apiId: str, format: OutputType, includeDirectives: bool = None
+        self, apiId: str, format: OutputTypeType, includeDirectives: bool = None
     ) -> GetIntrospectionSchemaResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.get_introspection_schema)
-        [Show boto3-stubs documentation](./client.md#get-introspection-schema)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.get_introspection_schema)
+        [Show boto3-stubs documentation](./client.md#get_introspection_schema)
         """
 
     def get_resolver(self, apiId: str, typeName: str, fieldName: str) -> GetResolverResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.get_resolver)
-        [Show boto3-stubs documentation](./client.md#get-resolver)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.get_resolver)
+        [Show boto3-stubs documentation](./client.md#get_resolver)
         """
 
     def get_schema_creation_status(self, apiId: str) -> GetSchemaCreationStatusResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.get_schema_creation_status)
-        [Show boto3-stubs documentation](./client.md#get-schema-creation-status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.get_schema_creation_status)
+        [Show boto3-stubs documentation](./client.md#get_schema_creation_status)
         """
 
     def get_type(
-        self, apiId: str, typeName: str, format: TypeDefinitionFormat
+        self, apiId: str, typeName: str, format: TypeDefinitionFormatType
     ) -> GetTypeResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.get_type)
-        [Show boto3-stubs documentation](./client.md#get-type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.get_type)
+        [Show boto3-stubs documentation](./client.md#get_type)
         """
 
     def list_api_keys(
         self, apiId: str, nextToken: str = None, maxResults: int = None
     ) -> ListApiKeysResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.list_api_keys)
-        [Show boto3-stubs documentation](./client.md#list-api-keys)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.list_api_keys)
+        [Show boto3-stubs documentation](./client.md#list_api_keys)
         """
 
     def list_data_sources(
         self, apiId: str, nextToken: str = None, maxResults: int = None
     ) -> ListDataSourcesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.list_data_sources)
-        [Show boto3-stubs documentation](./client.md#list-data-sources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.list_data_sources)
+        [Show boto3-stubs documentation](./client.md#list_data_sources)
         """
 
     def list_functions(
         self, apiId: str, nextToken: str = None, maxResults: int = None
     ) -> ListFunctionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.list_functions)
-        [Show boto3-stubs documentation](./client.md#list-functions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.list_functions)
+        [Show boto3-stubs documentation](./client.md#list_functions)
         """
 
     def list_graphql_apis(
         self, nextToken: str = None, maxResults: int = None
     ) -> ListGraphqlApisResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.list_graphql_apis)
-        [Show boto3-stubs documentation](./client.md#list-graphql-apis)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.list_graphql_apis)
+        [Show boto3-stubs documentation](./client.md#list_graphql_apis)
         """
 
     def list_resolvers(
         self, apiId: str, typeName: str, nextToken: str = None, maxResults: int = None
     ) -> ListResolversResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.list_resolvers)
-        [Show boto3-stubs documentation](./client.md#list-resolvers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.list_resolvers)
+        [Show boto3-stubs documentation](./client.md#list_resolvers)
         """
 
     def list_resolvers_by_function(
         self, apiId: str, functionId: str, nextToken: str = None, maxResults: int = None
     ) -> ListResolversByFunctionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.list_resolvers_by_function)
-        [Show boto3-stubs documentation](./client.md#list-resolvers-by-function)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.list_resolvers_by_function)
+        [Show boto3-stubs documentation](./client.md#list_resolvers_by_function)
         """
 
     def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.list_tags_for_resource)
-        [Show boto3-stubs documentation](./client.md#list-tags-for-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.list_tags_for_resource)
+        [Show boto3-stubs documentation](./client.md#list_tags_for_resource)
         """
 
     def list_types(
         self,
         apiId: str,
-        format: TypeDefinitionFormat,
+        format: TypeDefinitionFormatType,
         nextToken: str = None,
         maxResults: int = None,
     ) -> ListTypesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.list_types)
-        [Show boto3-stubs documentation](./client.md#list-types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.list_types)
+        [Show boto3-stubs documentation](./client.md#list_types)
         """
 
     def start_schema_creation(
         self, apiId: str, definition: Union[bytes, IO[bytes]]
     ) -> StartSchemaCreationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.start_schema_creation)
-        [Show boto3-stubs documentation](./client.md#start-schema-creation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.start_schema_creation)
+        [Show boto3-stubs documentation](./client.md#start_schema_creation)
         """
 
     def tag_resource(self, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.tag_resource)
-        [Show boto3-stubs documentation](./client.md#tag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.tag_resource)
+        [Show boto3-stubs documentation](./client.md#tag_resource)
         """
 
     def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.untag_resource)
-        [Show boto3-stubs documentation](./client.md#untag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.untag_resource)
+        [Show boto3-stubs documentation](./client.md#untag_resource)
         """
 
     def update_api_cache(
-        self, apiId: str, ttl: int, apiCachingBehavior: ApiCachingBehavior, type: ApiCacheType
+        self,
+        apiId: str,
+        ttl: int,
+        apiCachingBehavior: ApiCachingBehaviorType,
+        type: ApiCacheTypeType,
     ) -> UpdateApiCacheResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.update_api_cache)
-        [Show boto3-stubs documentation](./client.md#update-api-cache)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.update_api_cache)
+        [Show boto3-stubs documentation](./client.md#update_api_cache)
         """
 
     def update_api_key(
         self, apiId: str, id: str, description: str = None, expires: int = None
     ) -> UpdateApiKeyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.update_api_key)
-        [Show boto3-stubs documentation](./client.md#update-api-key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.update_api_key)
+        [Show boto3-stubs documentation](./client.md#update_api_key)
         """
 
     def update_data_source(
         self,
         apiId: str,
         name: str,
-        type: DataSourceType,
+        type: DataSourceTypeType,
         description: str = None,
         serviceRoleArn: str = None,
         dynamodbConfig: "DynamodbDataSourceConfigTypeDef" = None,
@@ -455,8 +458,8 @@ class AppSyncClient:
         relationalDatabaseConfig: "RelationalDatabaseDataSourceConfigTypeDef" = None,
     ) -> UpdateDataSourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.update_data_source)
-        [Show boto3-stubs documentation](./client.md#update-data-source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.update_data_source)
+        [Show boto3-stubs documentation](./client.md#update_data_source)
         """
 
     def update_function(
@@ -472,8 +475,8 @@ class AppSyncClient:
         syncConfig: "SyncConfigTypeDef" = None,
     ) -> UpdateFunctionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.update_function)
-        [Show boto3-stubs documentation](./client.md#update-function)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.update_function)
+        [Show boto3-stubs documentation](./client.md#update_function)
         """
 
     def update_graphql_api(
@@ -481,15 +484,15 @@ class AppSyncClient:
         apiId: str,
         name: str,
         logConfig: "LogConfigTypeDef" = None,
-        authenticationType: AuthenticationType = None,
+        authenticationType: AuthenticationTypeType = None,
         userPoolConfig: "UserPoolConfigTypeDef" = None,
         openIDConnectConfig: "OpenIDConnectConfigTypeDef" = None,
         additionalAuthenticationProviders: List["AdditionalAuthenticationProviderTypeDef"] = None,
         xrayEnabled: bool = None,
     ) -> UpdateGraphqlApiResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.update_graphql_api)
-        [Show boto3-stubs documentation](./client.md#update-graphql-api)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.update_graphql_api)
+        [Show boto3-stubs documentation](./client.md#update_graphql_api)
         """
 
     def update_resolver(
@@ -500,28 +503,28 @@ class AppSyncClient:
         dataSourceName: str = None,
         requestMappingTemplate: str = None,
         responseMappingTemplate: str = None,
-        kind: ResolverKind = None,
+        kind: ResolverKindType = None,
         pipelineConfig: "PipelineConfigTypeDef" = None,
         syncConfig: "SyncConfigTypeDef" = None,
         cachingConfig: "CachingConfigTypeDef" = None,
     ) -> UpdateResolverResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.update_resolver)
-        [Show boto3-stubs documentation](./client.md#update-resolver)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.update_resolver)
+        [Show boto3-stubs documentation](./client.md#update_resolver)
         """
 
     def update_type(
-        self, apiId: str, typeName: str, format: TypeDefinitionFormat, definition: str = None
+        self, apiId: str, typeName: str, format: TypeDefinitionFormatType, definition: str = None
     ) -> UpdateTypeResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Client.update_type)
-        [Show boto3-stubs documentation](./client.md#update-type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Client.update_type)
+        [Show boto3-stubs documentation](./client.md#update_type)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_api_keys"]) -> ListApiKeysPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Paginator.ListApiKeys)[Show boto3-stubs documentation](./paginators.md#listapikeyspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Paginator.ListApiKeys)[Show boto3-stubs documentation](./paginators.md#listapikeyspaginator)
         """
 
     @overload
@@ -529,13 +532,13 @@ class AppSyncClient:
         self, operation_name: Literal["list_data_sources"]
     ) -> ListDataSourcesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Paginator.ListDataSources)[Show boto3-stubs documentation](./paginators.md#listdatasourcespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Paginator.ListDataSources)[Show boto3-stubs documentation](./paginators.md#listdatasourcespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_functions"]) -> ListFunctionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Paginator.ListFunctions)[Show boto3-stubs documentation](./paginators.md#listfunctionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Paginator.ListFunctions)[Show boto3-stubs documentation](./paginators.md#listfunctionspaginator)
         """
 
     @overload
@@ -543,13 +546,13 @@ class AppSyncClient:
         self, operation_name: Literal["list_graphql_apis"]
     ) -> ListGraphqlApisPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Paginator.ListGraphqlApis)[Show boto3-stubs documentation](./paginators.md#listgraphqlapispaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Paginator.ListGraphqlApis)[Show boto3-stubs documentation](./paginators.md#listgraphqlapispaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_resolvers"]) -> ListResolversPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Paginator.ListResolvers)[Show boto3-stubs documentation](./paginators.md#listresolverspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Paginator.ListResolvers)[Show boto3-stubs documentation](./paginators.md#listresolverspaginator)
         """
 
     @overload
@@ -557,11 +560,11 @@ class AppSyncClient:
         self, operation_name: Literal["list_resolvers_by_function"]
     ) -> ListResolversByFunctionPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Paginator.ListResolversByFunction)[Show boto3-stubs documentation](./paginators.md#listresolversbyfunctionpaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Paginator.ListResolversByFunction)[Show boto3-stubs documentation](./paginators.md#listresolversbyfunctionpaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_types"]) -> ListTypesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Paginator.ListTypes)[Show boto3-stubs documentation](./paginators.md#listtypespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Paginator.ListTypes)[Show boto3-stubs documentation](./paginators.md#listtypespaginator)
         """
