@@ -34,7 +34,7 @@ from typing import Iterator
 
 from botocore.paginate import Paginator as Boto3Paginator
 
-from .literals import TypeDefinitionFormat
+from .literals import TypeDefinitionFormatType
 from .type_defs import (
     ListApiKeysResponseTypeDef,
     ListDataSourcesResponseTypeDef,
@@ -59,100 +59,100 @@ __all__ = (
 
 class ListApiKeysPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Paginator.ListApiKeys)[Show boto3-stubs documentation](./paginators.md#listapikeyspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Paginator.ListApiKeys)[Show boto3-stubs documentation](./paginators.md#listapikeyspaginator)
     """
 
     def paginate(
         self, apiId: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListApiKeysResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Paginator.ListApiKeys.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Paginator.ListApiKeys.paginate)
         [Show boto3-stubs documentation](./paginators.md#listapikeyspaginator)
         """
 
 
 class ListDataSourcesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Paginator.ListDataSources)[Show boto3-stubs documentation](./paginators.md#listdatasourcespaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Paginator.ListDataSources)[Show boto3-stubs documentation](./paginators.md#listdatasourcespaginator)
     """
 
     def paginate(
         self, apiId: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListDataSourcesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Paginator.ListDataSources.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Paginator.ListDataSources.paginate)
         [Show boto3-stubs documentation](./paginators.md#listdatasourcespaginator)
         """
 
 
 class ListFunctionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Paginator.ListFunctions)[Show boto3-stubs documentation](./paginators.md#listfunctionspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Paginator.ListFunctions)[Show boto3-stubs documentation](./paginators.md#listfunctionspaginator)
     """
 
     def paginate(
         self, apiId: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListFunctionsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Paginator.ListFunctions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Paginator.ListFunctions.paginate)
         [Show boto3-stubs documentation](./paginators.md#listfunctionspaginator)
         """
 
 
 class ListGraphqlApisPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Paginator.ListGraphqlApis)[Show boto3-stubs documentation](./paginators.md#listgraphqlapispaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Paginator.ListGraphqlApis)[Show boto3-stubs documentation](./paginators.md#listgraphqlapispaginator)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListGraphqlApisResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Paginator.ListGraphqlApis.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Paginator.ListGraphqlApis.paginate)
         [Show boto3-stubs documentation](./paginators.md#listgraphqlapispaginator)
         """
 
 
 class ListResolversPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Paginator.ListResolvers)[Show boto3-stubs documentation](./paginators.md#listresolverspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Paginator.ListResolvers)[Show boto3-stubs documentation](./paginators.md#listresolverspaginator)
     """
 
     def paginate(
         self, apiId: str, typeName: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListResolversResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Paginator.ListResolvers.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Paginator.ListResolvers.paginate)
         [Show boto3-stubs documentation](./paginators.md#listresolverspaginator)
         """
 
 
 class ListResolversByFunctionPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Paginator.ListResolversByFunction)[Show boto3-stubs documentation](./paginators.md#listresolversbyfunctionpaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Paginator.ListResolversByFunction)[Show boto3-stubs documentation](./paginators.md#listresolversbyfunctionpaginator)
     """
 
     def paginate(
         self, apiId: str, functionId: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListResolversByFunctionResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Paginator.ListResolversByFunction.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Paginator.ListResolversByFunction.paginate)
         [Show boto3-stubs documentation](./paginators.md#listresolversbyfunctionpaginator)
         """
 
 
 class ListTypesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Paginator.ListTypes)[Show boto3-stubs documentation](./paginators.md#listtypespaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Paginator.ListTypes)[Show boto3-stubs documentation](./paginators.md#listtypespaginator)
     """
 
     def paginate(
         self,
         apiId: str,
-        format: TypeDefinitionFormat,
+        format: TypeDefinitionFormatType,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListTypesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appsync.html#AppSync.Paginator.ListTypes.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync.Paginator.ListTypes.paginate)
         [Show boto3-stubs documentation](./paginators.md#listtypespaginator)
         """
